/*FreeMind - A Program for creating and viewing Mindmaps
 *Copyright (C) 2000-2001  Joerg Mueller <joergmueller@bigfoot.com>
 *See COPYING for Details
 *
 *This program is free software; you can redistribute it and/or
 *modify it under the terms of the GNU General Public License
 *as published by the Free Software Foundation; either version 2
 *of the License, or (at your option) any later version.
 *
 *This program is distributed in the hope that it will be useful,
 *but WITHOUT ANY WARRANTY; without even the implied warranty of
 *MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *GNU General Public License for more details.
 *
 *You should have received a copy of the GNU General Public License
 *along with this program; if not, write to the Free Software
 *Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/*$Id: MapMouseWheelListener.java,v 1.8.18.1 2006/01/12 23:10:12 christianfoltin Exp $*/

package freemind.controller;

import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;

/**
 * The MouseListener which belongs to MapView
 */
public class MapMouseWheelListener implements MouseWheelListener {

    private final Controller c;
	private MouseWheelListener mListener;

    public MapMouseWheelListener(Controller controller) {
       c = controller; }

    public void mouseWheelMoved(MouseWheelEvent e) {
    		if(mListener != null) 
    			mListener.mouseWheelMoved(e);
   }

	public void register(MouseWheelListener handler) {
		mListener = handler;
	}
	
	public void deregister() {
		mListener = null;
	}
}
